@@ -27,7 +27,8 @@
 download_session_asset <- function(asset_id = 1,
                                    session_id = 9807,
                                    file_name = NULL,
-                                   target_dir = tempdir(),
+                                   target_dir = paste0("./", session_id),
+                                   # target_dir = tempdir(),
                                    vb = FALSE,
                                    rq = NULL) {
   # Check parameters
@@ -57,6 +58,9 @@ download_session_asset <- function(asset_id = 1,
     }
     rq <- databraryr::make_default_request()
   }
+  
+  
+  
   this_rq <- rq %>%
     httr2::req_url(sprintf(DOWNLOAD_FILE, session_id, asset_id)) %>%
     httr2::req_progress()
@@ -139,4 +143,3 @@ download_session_asset <- function(asset_id = 1,
     write_file
   }
 }
-  
\ No newline at end of file
