@@ -1,15 +1,21 @@
-#' Assets in Databrary Volume.
+#' List Assets in a Databrary Volume.
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' This function has been deprecated in favor of `list_volume_assets()`.
 #'
 #' @param vol_id Target volume number.
 #' @param vb A boolean value.
 #' @returns A data frame with information about all assets in a volume.
+#'
 #' @examples
 #' \donttest{
 #' list_assets_in_volume() # Assets in volume 2
 #' #' }
+#'
 #' @export
 list_assets_in_volume <- function(vol_id = 2, vb = FALSE) {
-  
   # Check parameters
   assertthat::assert_that(length(vol_id) == 1)
   assertthat::assert_that(is.numeric(vol_id))
@@ -18,30 +24,21 @@ list_assets_in_volume <- function(vol_id = 2, vb = FALSE) {
   assertthat::assert_that(length(vb) == 1)
   assertthat::assert_that(is.logical(vb))
   
-  # Error handling
-  if (!is.numeric(vol_id)) {
-    stop("vol_id must be numeric.")
-  }
-  if (vol_id < 1) {
-    stop("vol_id must be >= 1.")
-  }
-  if (!is.logical(vb)) {
-    stop("vb must be a logical value.")
-  }
-
   sl <- list_sessions(vol_id = vol_id, vb = vb)
   if (!is.null(sl)) {
-    if (vb) message(" Session data exists.")
+    if (vb)
+      message(" Session data exists.")
     s_ids <- sl$session_id
     if (length(s_ids) >= 1) {
       a <- lapply(s_ids, list_assets_in_session, vb = vb)
       a <- plyr::rbind.fill(a)
-      return(a)      
+      return(a)
     } else {
-     NULL 
+      NULL
     }
   } else {
-    if (vb) message(paste0(" Session list for volume ", vol_id, " unavailable."))
+    if (vb)
+      message(paste0(" Session list for volume ", vol_id, " unavailable."))
     return(NULL)
   }
 }
