@@ -31,7 +31,7 @@ list_volume_owners <- function(vol_id = 1,
   if (is.null(rq)) {
     if (vb) {
       message("NULL request object. Will generate default.")
-      message("\nNot logged in. Only public information will be returned.")  
+      message("Not logged in. Only public information will be returned.")  
     }
     rq <- databraryr::make_default_request()
   }
