@@ -30,7 +30,7 @@ search_for_funder <-
     if (is.null(rq)) {
       if (vb) {
         message("NULL request object. Will generate default.")
-        message("\nNot logged in. Only public information will be returned.")  
+        message("Not logged in. Only public information will be returned.")  
       }
       rq <- databraryr::make_default_request()
     }
